## -*- mode: autoconf -*-

##
## This file is part of the Cube software (http://www.scalasca.org)
##
## Copyright (c) 2015, 2016
## Forschungszentrum Juelich GmbH, Germany
##
## This software may be modified and distributed under the terms of
## a BSD-style license.  See the COPYING file in the package base
## directory for details.
##


##
## Internally used macros
##


dnl This macro checks for the availability of a  tool for the required component
dnl
dnl Input:
dnl   $1 component short name (used as prefix to the config-tool and all corresponding variables)
dnl   $2 configure option name (a more descriptive name used for the --with-<component> option)
dnl
dnl Output:
dnl  $1_prog    : the detected config tool
dnl
dnl The macro will check for the availablility of either '$1-prog'
dnl
AC_DEFUN([_AX_HAVE_TOOL],[

    m4_ifblank([$1], [m4_fatal([The argument 1 may not be empty.])])
    m4_ifblank([$2], [m4_fatal([The argument 2 may not be empty.])])

    AS_UNSET([$1_prog])
    AS_UNSET(m4_toupper($1_prog))
    

    AC_ARG_WITH([$1],
        [AS_HELP_STRING([--with-$1[[=DIR]]],
            [Provide path to a pre-installed $1 . Autodetected if already in $PATH.])],
        [AS_IF([test "x$withval" != "xno"],
              [AC_PATH_PROG([$1_prog],[$1],[],[$withval $withval/bin $PATH])])],
            [AC_PATH_PROG([$1_prog],[$1],[],[$PATH])])

    AS_IF([test "x${$1_prog}" != "x"],
          [dnl $1 tool found, do further processing
            m4_toupper($1_prog)=${$1_prog}
            AC_SUBST(m4_toupper($1_prog))
            AC_DEFINE(AS_TR_CPP(m4_toupper(HAVE_$1)),[1],[Define if $1 support is available.])
           ])
])



dnl This macro will search for a suitable config tool for the Cube library
dnl
dnl Input:
dnl   $1 required interface version
dnl
dnl Output:
dnl   Defines HAVE_CUBE_LIBRARY
dnl
AC_DEFUN([AX_PANDOC],[
    _AX_HAVE_TOOL([pandoc], [pandoc])
])
